aboutsummaryrefslogtreecommitdiff
path: root/scripts/git/git-pull-all.sh
diff options
context:
space:
mode:
Diffstat (limited to 'scripts/git/git-pull-all.sh')
-rwxr-xr-xscripts/git/git-pull-all.sh28
1 files changed, 7 insertions, 21 deletions
diff --git a/scripts/git/git-pull-all.sh b/scripts/git/git-pull-all.sh
index 52a5c6140c..bbe2576d8e 100755
--- a/scripts/git/git-pull-all.sh
+++ b/scripts/git/git-pull-all.sh
@@ -20,7 +20,7 @@ usage()
echo
echo " optional:"
echo " TOR_MASTER: the name of the directory containing the tor.git clone"
- echo " The tor master git directory is \$GIT_PATH/\$TOR_MASTER"
+ echo " The primary tor git directory is \$GIT_PATH/\$TOR_MASTER"
echo " (default: tor; current: $TOR_MASTER_NAME)"
echo " TOR_WKT_NAME: the name of the directory containing the tor"
echo " worktrees. The tor worktrees are:"
@@ -37,7 +37,7 @@ usage()
# Where are all those git repositories?
GIT_PATH=${TOR_FULL_GIT_PATH:-"FULL_PATH_TO_GIT_REPOSITORY_DIRECTORY"}
# The tor master git repository directory from which all the worktree have
# been created.
TOR_MASTER_NAME=${TOR_MASTER_NAME:-"tor"}
# The worktrees location (directory).
@@ -51,7 +51,7 @@ set -e
eval "$(git-list-tor-branches.sh -b)"
set +e
-# The master branch path has to be the main repository thus contains the
+# The main branch path has to be the main repository thus contains the
# origin that will be used to fetch the updates. All the worktrees are created
# from that repository.
ORIGIN_PATH="$GIT_PATH/$TOR_MASTER_NAME"
@@ -159,20 +159,7 @@ function goto_repo
function fetch_origin
{
local cmd="git fetch origin"
- printf " %s Fetching origin..." "$MARKER"
- if [ $DRY_RUN -eq 0 ]; then
- msg=$( eval "$cmd" 2>&1 )
- validate_ret $? "$msg"
- else
- printf "\\n %s\\n" "${IWTH}$cmd${CNRM}"
- fi
-}
-
-# Fetch tor-github pull requests. No arguments.
-function fetch_tor_github
-{
- local cmd="git fetch tor-github"
- printf " %s Fetching tor-github..." "$MARKER"
+ printf "%s Fetching origin..." "$MARKER"
if [ $DRY_RUN -eq 0 ]; then
msg=$( eval "$cmd" 2>&1 )
validate_ret $? "$msg"
@@ -185,7 +172,7 @@ function fetch_tor_github
function fetch_tor_gitlab
{
local cmd="git fetch tor-gitlab"
- printf " %s Fetching tor-gitlab..." "$MARKER"
+ printf "%s Fetching tor-gitlab..." "$MARKER"
if [ $DRY_RUN -eq 0 ]; then
msg=$( eval "$cmd" 2>&1 )
validate_ret $? "$msg"
@@ -198,11 +185,10 @@ function fetch_tor_gitlab
# Entry point #
###############
-# First, fetch tor-github.
+# Get into our origin repository.
goto_repo "$ORIGIN_PATH"
-fetch_tor_github
-# Then tor-gitlab
+# First, fetch tor-gitlab
fetch_tor_gitlab
# Then, fetch the origin.
@@ -37,7 +37,7 @@ usage()
# Where are all those git repositories?
GIT_PATH=${TOR_FULL_GIT_PATH:-"FULL_PATH_TO_GIT_REPOSITORY_DIRECTORY"}
-# The tor master git repository directory from which all the worktree have
+# The primary tor git repository directory from which all the worktree have
# been created.
TOR_MASTER_NAME=${TOR_MASTER_NAME:-"tor"}